Class: Votd::NetBible
- Inherits:
-
Base
- Object
- Base
- Votd::NetBible
- Defined in:
- lib/votd/netbible.rb
Overview
Retrieves a Verse of the Day from https://labs.bible.org using the NETBible translation.
Constant Summary collapse
- BIBLE_VERSION =
The name of the Bible Translation that this module generates
"NETBible"- BIBLE_VERSION_NAME =
The full name of the Bible translation
"NET Bible"- ENDPOINT_URL =
The URL of the API gateway
"https://labs.bible.org/api/?passage=votd&type=json"- NET_BIBLE_URL =
The URL of the website to view the verse (used in
.link) "https://netbible.org/bible"